================================================
Databricks MLflow Model Registry Webhooks Client
================================================

`Databricks Model Registry Webhooks <https://docs.databricks.com/applications/mlflow/model-registry-webhooks.html>`_ enable you to automate and integrate your machine learning pipelines with a variety of CI/CD tools and workflows. Databricks Model Registry Webhooks integrate with the `Databricks MLflow Model Registry <https://databricks.com/product/mlflow-model-registry>`_ to provide event-based triggers for Model Registry actions, such as the creation of a new model or the transition of a model version into production.

Use cases for Databricks Model Registry Webhooks include triggering CI builds when a new model version is created, notifying team members each time a model transition to production is requested, and much more.

This package provides a Python client for managing Databricks Model Registry Webhooks. For more information about the feature and Python client usage, explore the documentation at https://docs.databricks.com/applications/mlflow/model-registry-webhooks.html.
